@@ -72,7 +72,6 @@ __MERCHANT_CUSTOMER_TRANSACTION_SCHEMA = {
 
 __MERCHANT_CUSTOMER_REWARD_SCHEMA = {
                         
-                            #customer key
                             bigquery.SchemaField('Key', 'STRING'),
                             bigquery.SchemaField('CustomerKey', 'STRING'),
                             bigquery.SchemaField('MerchantKey', 'STRING'),
@@ -90,6 +89,25 @@ __MERCHANT_CUSTOMER_REWARD_SCHEMA = {
                             bigquery.SchemaField('UpdatedDateTime', 'DATETIME'),
                             }
 
+
+
+__MERCHANT_CUSTOMER_REDEMPTION_SCHEMA = {
+                        
+                            bigquery.SchemaField('Key', 'STRING'),
+                            bigquery.SchemaField('CustomerKey', 'STRING'),
+                            bigquery.SchemaField('MerchantKey', 'STRING'),
+                            bigquery.SchemaField('RedeemOutlet', 'STRING'),
+                            bigquery.SchemaField('TransactionId', 'STRING'),
+                            bigquery.SchemaField('RedeemAmount', 'FLOAT64'),
+                            bigquery.SchemaField('RewardFormat', 'STRING'),
+                            bigquery.SchemaField('VoucherKeysList', 'STRING'),
+                            bigquery.SchemaField('RedeemedDateTime', 'DATETIME'),
+                            bigquery.SchemaField('Reverted', 'BOOLEAN'),
+                            bigquery.SchemaField('RevertedDateTime', 'DATETIME'),
+                            bigquery.SchemaField('UpdatedDateTime', 'DATETIME'),
+                            }
+
+
 __REGISTERED_MERCHANT_SCHEMA = {
                         
                             #customer key
@@ -107,6 +125,7 @@ CUSTOMER_TRANSACTION_TEMPLATE               = 'customer_transaction'
 REGISTERED_MERCHANT_TEMPLATE                = 'registered_merchant'
 MERCHANT_REGISTERED_CUSTOMER_TEMPLATE       = 'merchant_registered_customer'
 MERCHANT_CUSTOMER_REWARD_TEMPLATE           = 'customer_reward'
+MERCHANT_CUSTOMER_REDEMPTION_TEMPLATE       = 'customer_reward'
     
 
 TABLE_SCHEME_TEMPLATE = {
@@ -115,5 +134,6 @@ TABLE_SCHEME_TEMPLATE = {
                     REGISTERED_MERCHANT_TEMPLATE            : __REGISTERED_MERCHANT_SCHEMA,
                     MERCHANT_REGISTERED_CUSTOMER_TEMPLATE   : __MERCHANT_REGISTERED_CUSTOMER_SCHEMA,
                     CUSTOMER_TRANSACTION_TEMPLATE           : __MERCHANT_CUSTOMER_TRANSACTION_SCHEMA,
-                    MERCHANT_CUSTOMER_REWARD_TEMPLATE       : __MERCHANT_CUSTOMER_REWARD_SCHEMA
+                    MERCHANT_CUSTOMER_REWARD_TEMPLATE       : __MERCHANT_CUSTOMER_REWARD_SCHEMA,
+                    MERCHANT_CUSTOMER_REDEMPTION_TEMPLATE   : __MERCHANT_CUSTOMER_REDEMPTION_SCHEMA,
     }
